@@ -1036,9 +1036,10 @@ char* utf8_to_europe(const char* str, char ch) {
         }
         if (EUROPE_UNICODE_TABLE_MAX <= n) {
           buf[j++] = '?';
+          i += (len1 - 1);
         }
       } else {
-        buf[j++] = str[i];
+        buf[j++] = (a0 & (unsigned char)0x80)?'?':a0;
       }
       i++;
     }
@@ -1145,9 +1146,10 @@ char* utf8_to_eucjp(const char *str) {
 
         if (min < 0 || unicode_eucjp[pos][0] != a1) {
           buf[j++] = '?';
+          i += (len1 - 1);
         }
       } else {
-        buf[j++] = str[i];
+        buf[j++] = (a0 & (unsigned char)0x80)?'?':a0;
       }
       i++;
     }
@@ -2145,9 +2147,10 @@ char* utf8_to_euckr(const char* str) {
 
         if (min < 0 || unicode_euckr[pos][0] != a1) {
           buf[j++] = '?';
+          i += (len1 - 1);
         }
       } else {
-        buf[j++] = str[i];
+        buf[j++] = (a0 & (unsigned char)0x80)?'?':a0;
       }
       i++;
     }
@@ -2317,12 +2320,14 @@ char* utf8_to_gbk(const char* str) {
             i += (utf8_len(str[i])-1);
           } else {
             buf[j++] = '?';
+            i += (len1 - 1);
           }
         } else {
           buf[j++] = '?';
+          i += (len1 - 1);
         }
       } else {
-        buf[j++] = str[i];
+        buf[j++] = (a0 & (unsigned char)0x80)?'?':a0;
       }
       i++;
     }
@@ -2512,9 +2517,10 @@ char* utf8_to_big5(const char* str) {
 
         if (min < 0 || unicode_big5[pos][0] != a1) {
           buf[j++] = '?';
+          i += (len1 - 1);
         }
       } else {
-        buf[j++] = str[i];
+        buf[j++] = (a0 & (unsigned char)0x80)?'?':a0;
       }
       i++;
     }
